@@ -6,12 +6,12 @@
 
 import unittest
 
-# Really do want "import *" to get all the test clases:
+# Really do want "import *" to get all the test classes:
 from common_BioSQL import *  # noqa: F403
+from common_BioSQL import check_config
 
 # Import these explicitly to avoid flake8 F405 below:
-from common_BioSQL import load_biosql_ini, check_config
-
+from common_BioSQL import load_biosql_ini
 
 DBDRIVER = "mysql.connector"
 DBTYPE = "mysql"
